/*
 * Copyright (C) 2010 Google Inc.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package com.google.gson.jf;

import com.google.gson.*;
import com.google.gson.common.*;
import com.google.gson.reflect.TypeToken;

import java.io.*;
import java.util.Arrays;
import java.util.List;

import com.google.gson.stream.*;
import junit.framework.TestCase;

/**
 * @author Jesse Wilson
 */
public final class CommentsTest extends TestCase {

  /**
   * Test for issue 212.
   */
  public void testParseComments() {
    String json = "[\n"
        + "  // this is a comment\n"
        + "  \"a\",\n"
        + "  /* this is another comment */\n"
        + "  \"b\",\n"
        + "  # this is yet another comment\n"
        + "  \"c\"\n"
        + "]";

    List<String> abc = new GsonBuilder().setLenient().create().fromJson(json, new TypeToken<List<String>>() {}.getType());
    assertEquals(Arrays.asList("a", "b", "c"), abc);
  }

  public void testWriteComments() throws IOException {
    String expectedJson = "// comment at file head\n"
        + "[\n"
        + "  // comment directly after context\n"
        + "  \"a\",\n"
        + "  // comment before context\n"
        + "  {\n"
        + "    // comment directly after object context\n"
        + "    \"b\": \"c\",\n"
        + "    // comment before name, after value\n"
        + "    \"d\": \"e\"\n"
        + "  }\n"
        + "  // comment before context end\n"
        + "]\n"
        + "// comment behind the object";

    StringWriter sw = new StringWriter();
    JsonWriter jw = new JsonWriter(sw);
    jw.setLenient(true);
    jw.setIndent("  ");

    jw.comment("comment at file head")
      .beginArray()
        .comment("comment directly after context")
        .value("a")
        .comment("comment before context")
        .beginObject()
          .comment("comment directly after object context")
          .name("b").value("c")
          .comment("comment before name, after value")
          .name("d").value("e")
        .endObject()
        .comment("comment before context end")
      .endArray()
      .comment("comment behind the object");

    jw.close();
    assertEquals(expectedJson, sw.toString());
    sw.close();
  }
}
